@@ -72,9 +72,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.12.5/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.6/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.12.5/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -632,7 +632,9 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -shared',
+ 'LDCXXSHARED': 'g++ -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                '-Wl,-z,relro -Wl,-z,now -Wl,-O1 -Wl,--sort-common '
+                '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
             '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDFLAGS_NODIST': '',
@@ -1164,7 +1166,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.6',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1290,9 +1292,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.6 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.6 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1322,8 +1324,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.12.5',
- 'abs_srcdir': '/build/python/src/Python-3.12.5',
+ 'abs_builddir': '/build/python/src/Python-3.12.6',
+ 'abs_srcdir': '/build/python/src/Python-3.12.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
